;; Generated package description from dmsg.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "dmsg" "0.2.0.20260512.141856" "Timestamped debug messages with backtrace support" '((emacs "28.1")) :commit "4bc23977a91fc0681632b7bd3a61d5b217909a98" :authors '(("Al Haji-Ali" . "abdo.haji.ali@gmail.com")) :maintainer '("Al Haji-Ali" . "abdo.haji.ali@gmail.com") :keywords '("maint" "tools") :url "https://github.com/haji-ali/dmsg.el")
